import { useState } from 'react'
import { Head, Link } from '@inertiajs/react'
import Layout from '../Layout'
import * as Tabs from '@radix-ui/react-tabs'
import * as Form from '@radix-ui/react-form'

export default function Index({ images, filters, auth }) {
  const [searchParams, setSearchParams] = useState({
    title_cont: filters.title_cont || '',
    tags_name_cont: filters.tags_name_cont || '',
    created_at_gteq: filters.created_at_gteq || '',
    created_at_lteq: filters.created_at_lteq || '',
  })

  const handleInputChange = (e) => {
    const { name, value } = e.target
    setSearchParams({ ...searchParams, [name]: value })
  }

  return (
    <Layout user={auth.user}>
      <Head title="My Images" />
      <div className="bg-white shadow overflow-hidden sm:rounded-lg">
        <div className="px-4 py-5 sm:px-6 flex justify-between items-center">
          <div>
            <h1 className="text-2xl font-bold text-gray-900">My Images</h1>
            <p className="mt-1 max-w-2xl text-sm text-gray-500">
              Manage your uploaded images
            </p>
          </div>
          {auth.user && (
            <Link
              href="/images/new"
              className="inline-flex items-center px-4 py-2 border border-transparent text-sm font-medium rounded-md shadow-sm text-white bg-indigo-600 hover:bg-indigo-700 focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-indigo-500"
            >
              Upload New Image
            </Link>
          )}
        </div>

        <Tabs.Root defaultValue="all" className="px-4 sm:px-6 pb-5">
          <Tabs.List className="flex space-x-4 border-b border-gray-200 mb-4">
            <Tabs.Trigger
              value="all"
              className="px-3 py-2 text-sm font-medium text-gray-500 hover:text-gray-700 hover:border-gray-300 focus:outline-none data-[state=active]:border-b-2 data-[state=active]:border-indigo-500 data-[state=active]:text-indigo-600"
            >
              All Images
            </Tabs.Trigger>
            <Tabs.Trigger
              value="search"
              className="px-3 py-2 text-sm font-medium text-gray-500 hover:text-gray-700 hover:border-gray-300 focus:outline-none data-[state=active]:border-b-2 data-[state=active]:border-indigo-500 data-[state=active]:text-indigo-600"
            >
              Search
            </Tabs.Trigger>
          </Tabs.List>

          <Tabs.Content value="all" className="focus:outline-none">
            {images.length > 0 ? (
              <div className="grid grid-cols-1 gap-6 sm:grid-cols-2 md:grid-cols-3 lg:grid-cols-4">
                {images.map((image) => (
                  <div
                    key={image.id}
                    className="bg-white overflow-hidden shadow rounded-lg"
                  >
                    <div className="relative pb-[75%]">
                      <img
                        src={image.file_url}
                        alt={image.title}
                        className="absolute h-full w-full object-cover"
                      />
                      <div className="absolute top-2 right-2">
                        <span
                          className={`inline-flex items-center px-2.5 py-0.5 rounded-full text-xs font-medium ${
                            image.status === 'pending'
                              ? 'bg-yellow-100 text-yellow-800'
                              : image.status === 'approved'
                              ? 'bg-green-100 text-green-800'
                              : 'bg-red-100 text-red-800'
                          }`}
                        >
                          {image.status}
                        </span>
                      </div>
                    </div>
                    <div className="px-4 py-4">
                      <h3 className="text-lg font-medium text-gray-900 truncate">
                        {image.title}
                      </h3>
                      <div className="mt-2 flex flex-wrap gap-1">
                        {image.tags.map((tag) => (
                          <span
                            key={tag.id}
                            className="inline-flex items-center px-2.5 py-0.5 rounded-full text-xs font-medium bg-indigo-100 text-indigo-800"
                          >
                            {tag.name}
                          </span>
                        ))}
                      </div>
                      <div className="mt-4 flex justify-between">
                        <Link
                          href={`/images/${image.id}`}
                          className="text-sm text-indigo-600 hover:text-indigo-900"
                        >
                          View details
                        </Link>
                        <span className="text-sm text-gray-500">
                          {new Date(image.created_at).toLocaleDateString()}
                        </span>
                      </div>
                    </div>
                  </div>
                ))}
              </div>
            ) : (
              <div className="text-center py-12">
                <svg
                  className="mx-auto h-12 w-12 text-gray-400"
                  fill="none"
                  viewBox="0 0 24 24"
                  stroke="currentColor"
                  aria-hidden="true"
                >
                  <path
                    strokeLinecap="round"
                    strokeLinejoin="round"
                    strokeWidth={2}
                    d="M4 16l4.586-4.586a2 2 0 012.828 0L16 16m-2-2l1.586-1.586a2 2 0 012.828 0L20 14m-6-6h.01M6 20h12a2 2 0 002-2V6a2 2 0 00-2-2H6a2 2 0 00-2 2v12a2 2 0 002 2z"
                  />
                </svg>
                <h3 className="mt-2 text-sm font-medium text-gray-900">
                  No images
                </h3>
                <p className="mt-1 text-sm text-gray-500">
                  Get started by uploading a new image.
                </p>
                <div className="mt-6">
                  <Link
                    href="/images/new"
                    className="inline-flex items-center px-4 py-2 border border-transparent shadow-sm text-sm font-medium rounded-md text-white bg-indigo-600 hover:bg-indigo-700 focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-indigo-500"
                  >
                    Upload New Image
                  </Link>
                </div>
              </div>
            )}
          </Tabs.Content>

          <Tabs.Content value="search" className="focus:outline-none">
            <Form.Root
              className="space-y-6"
              action="/images"
              method="get"
            >
              <div className="grid grid-cols-1 gap-y-6 gap-x-4 sm:grid-cols-6">
                <div className="sm:col-span-3">
                  <Form.Field name="q[title_cont]">
                    <Form.Label className="block text-sm font-medium text-gray-700">
                      Title
                    </Form.Label>
                    <Form.Control asChild>
                      <input
                        type="text"
                        name="q[title_cont]"
                        value={searchParams.title_cont}
                        onChange={handleInputChange}
                        className="mt-1 focus:ring-indigo-500 focus:border-indigo-500 block w-full shadow-sm sm:text-sm border-gray-300 rounded-md"
                        placeholder="Search by title"
                      />
                    </Form.Control>
                  </Form.Field>
                </div>

                <div className="sm:col-span-3">
                  <Form.Field name="q[tags_name_cont]">
                    <Form.Label className="block text-sm font-medium text-gray-700">
                      Tags
                    </Form.Label>
                    <Form.Control asChild>
                      <input
                        type="text"
                        name="q[tags_name_cont]"
                        value={searchParams.tags_name_cont}
                        onChange={handleInputChange}
                        className="mt-1 focus:ring-indigo-500 focus:border-indigo-500 block w-full shadow-sm sm:text-sm border-gray-300 rounded-md"
                        placeholder="Search by tag"
                      />
                    </Form.Control>
                  </Form.Field>
                </div>

                <div className="sm:col-span-3">
                  <Form.Field name="q[created_at_gteq]">
                    <Form.Label className="block text-sm font-medium text-gray-700">
                      From Date
                    </Form.Label>
                    <Form.Control asChild>
                      <input
                        type="date"
                        name="q[created_at_gteq]"
                        value={searchParams.created_at_gteq}
                        onChange={handleInputChange}
                        className="mt-1 focus:ring-indigo-500 focus:border-indigo-500 block w-full shadow-sm sm:text-sm border-gray-300 rounded-md"
                      />
                    </Form.Control>
                  </Form.Field>
                </div>

                <div className="sm:col-span-3">
                  <Form.Field name="q[created_at_lteq]">
                    <Form.Label className="block text-sm font-medium text-gray-700">
                      To Date
                    </Form.Label>
                    <Form.Control asChild>
                      <input
                        type="date"
                        name="q[created_at_lteq]"
                        value={searchParams.created_at_lteq}
                        onChange={handleInputChange}
                        className="mt-1 focus:ring-indigo-500 focus:border-indigo-500 block w-full shadow-sm sm:text-sm border-gray-300 rounded-md"
                      />
                    </Form.Control>
                  </Form.Field>
                </div>
              </div>

              <div className="flex justify-end">
                <button
                  type="submit"
                  className="inline-flex justify-center py-2 px-4 border border-transparent shadow-sm text-sm font-medium rounded-md text-white bg-indigo-600 hover:bg-indigo-700 focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-indigo-500"
                >
                  Search
                </button>
              </div>
            </Form.Root>
          </Tabs.Content>
        </Tabs.Root>
      </div>
    </Layout>
  )
}
